@@ -114,7 +114,7 @@ class UIAddressObjectMapper(ObjectMapper):
         'shortName': 'typename',
         'formalName': 'name',
         'postalCode': 'params__PostIndex__value',
-        'fullName': lambda data: '{} {}'.format(data['name'], data['typename']),
+        'fullName': 'hierarchy__mun__name_with_parents',
     }
 
 
