@@ -4,8 +4,9 @@ from __future__ import unicode_literals
 
 from abc import ABCMeta
 from abc import abstractproperty
-from collections import Mapping, defaultdict
+from collections import Mapping
 from collections import MutableMapping
+from collections import defaultdict
 from collections import namedtuple
 from datetime import date
 from datetime import datetime
@@ -20,11 +21,11 @@ from six import with_metaclass
 from m3_gar_client.constants import GAR_LEVELS
 
 
-FieldDescriptor = namedtuple('FieldDescriptor', ' '.join((
+FieldDescriptor = namedtuple('FieldDescriptor', [
     'data_type',
     'required',
     'description',
-)))
+])
 
 
 class ReadOnlyAttribute(object):
@@ -216,114 +217,139 @@ class AddressObject(ObjectBase):
     #: Поля объекта и признак обязательности значения.
     fields = {
         'id': FieldDescriptor(
-            _int,
-            True,
-            'Уникальный идентификатор записи (ключевое поле).',
+            data_type=_int,
+            required=True,
+            description='Уникальный идентификатор записи (ключевое поле).',
         ),
         'previous_id': FieldDescriptor(
-            _int,
-            False,
-            'Идентификатор записи связывания с предыдушей исторической записью.',
+            data_type=_int,
+            required=False,
+            description='Идентификатор записи связывания с предыдушей исторической записью.',
         ),
         'next_id': FieldDescriptor(
-            _int,
-            False,
-            'Идентификатор записи  связывания с последующей исторической записью.',
+            data_type=_int,
+            required=False,
+            description='Идентификатор записи  связывания с последующей исторической записью.',
         ),
         'obj_id': FieldDescriptor(
-            _int,
-            True,
-            'Глобальный уникальный идентификатор адресного объекта.',
+            data_type=_int,
+            required=True,
+            description='Глобальный уникальный идентификатор адресного объекта.',
         ),
         'guid': FieldDescriptor(
-            _uuid,
-            True,
-            'UUID адресного объекта.',
+            data_type=_uuid,
+            required=True,
+            description='UUID адресного объекта.',
         ),
         'level': FieldDescriptor(
-            partial(_choices, GAR_LEVELS, _int),
-            True,
-            'Уровень адресного объекта.',
+            data_type=partial(_choices, GAR_LEVELS, _int),
+            required=True,
+            description='Уровень адресного объекта.',
         ),
         'ifns_fl_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Код ИФНС для физических лиц.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код ИФНС для физических лиц.',
         ),
         'ifns_fl_territorial_district_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Код территориального участка ИФНС ФЛ.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код территориального участка ИФНС ФЛ.',
         ),
         'ifns_ul_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Код ИФНС для юридических лиц.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код ИФНС для юридических лиц.',
         ),
         'ifns_ul_territorial_district_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Код территориального участка ИФНС ЮЛ.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код территориального участка ИФНС ЮЛ.',
         ),
         'okato': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'ОКАТО.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='ОКАТО.',
         ),
         'oktmo': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'ОКТМО.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='ОКТМО.',
         ),
         'kladr_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Код адресного объекта одной строкой с признаком актуальности из КЛАДР 4.0.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код адресного объекта одной строкой с признаком актуальности из КЛАДР 4.0.',
         ),
         'kladr_plain_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Код адресного объекта из КЛАДР 4.0 одной строкой без признака актуальности (последних двух цифр).',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код адресного объекта из КЛАДР 4.0 одной строкой без признака актуальности (последних двух цифр).',
         ),
         'short_name': FieldDescriptor(
-            _unicode,
-            True,
-            'Краткое наименование типа объекта',
+            data_type=_unicode,
+            required=True,
+            description='Краткое наименование типа объекта',
         ),
         'official_name': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Официальное наименование',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Официальное наименование',
         ),
         'formal_name': FieldDescriptor(
-            _unicode,
-            True,
-            'Формализованное наименование',
+            data_type=_unicode,
+            required=True,
+            description='Формализованное наименование',
         ),
         'postal_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Почтовый индекс',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Почтовый индекс',
         ),
         'date_of_creation': FieldDescriptor(
-            _date,
-            True,
-            'Начало действия записи',
+            data_type=_date,
+            required=True,
+            description='Начало действия записи',
         ),
         'date_of_update': FieldDescriptor(
-            _date,
-            True,
-            'Дата  внесения (обновления) записи',
+            data_type=_date,
+            required=True,
+            description='Дата  внесения (обновления) записи',
         ),
         'date_of_expiration': FieldDescriptor(
-            _date,
-            True,
-            'Окончание действия записи',
+            data_type=_date,
+            required=True,
+            description='Окончание действия записи',
         ),
         'full_name': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Полный адрес',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Полный адрес',
+        ),
+        'region_code': FieldDescriptor(
+            data_type=_int,
+            required=True,
+            description='Код региона',
+        ),
+        'adm_parent_obj_id': FieldDescriptor(
+            data_type=_int,
+            required=False,
+            description='Родительский obj_id в административной иерархии'
+        ),
+        'adm_parent_guid': FieldDescriptor(
+            data_type=_uuid,
+            required=False,
+            description='Родительский guid в административной иерархии'
+        ),
+        'mun_parent_obj_id': FieldDescriptor(
+            data_type=_int,
+            required=False,
+            description='Родительский obj_id в муниципальной иерархии'
+        ),
+        'mun_parent_guid': FieldDescriptor(
+            data_type=_uuid,
+            required=False,
+            description='Родительский guid в муниципальной иерархии'
         ),
     }
 
@@ -335,84 +361,109 @@ class House(ObjectBase):
 
     fields = {
         'id': FieldDescriptor(
-            _uuid,
-            True,
-            'Уникальный идентификатор записи дома',
+            data_type=_int,
+            required=True,
+            description='Уникальный идентификатор записи дома',
         ),
         'obj_id': FieldDescriptor(
-            _int,
-            True,
-            'Глобальный уникальный идентификатор дома',
+            data_type=_int,
+            required=True,
+            description='Глобальный уникальный идентификатор дома',
         ),
         'guid': FieldDescriptor(
-            _uuid,
-            True,
-            'UUID адресного объекта.',
+            data_type=_uuid,
+            required=True,
+            description='UUID адресного объекта.',
         ),
         'ifns_fl_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Код ИФНС для физических лиц.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код ИФНС для физических лиц.',
         ),
         'ifns_fl_territorial_district_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Код территориального участка ИФНС ФЛ.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код территориального участка ИФНС ФЛ.',
         ),
         'ifns_ul_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Код ИФНС для юридических лиц.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код ИФНС для юридических лиц.',
         ),
         'ifns_ul_territorial_district_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Код территориального участка ИФНС ЮЛ.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Код территориального участка ИФНС ЮЛ.',
         ),
         'okato': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'ОКАТО.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='ОКАТО.',
         ),
         'oktmo': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'ОКТМО.',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='ОКТМО.',
         ),
         'postal_code': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Почтовый индекс',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Почтовый индекс',
         ),
         'house_number': FieldDescriptor(
-            _unicode,
-            True,
-            'Номер дома',
+            data_type=_unicode,
+            required=True,
+            description='Номер дома',
         ),
         'building_number': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Номер корпуса',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Номер корпуса',
         ),
         'structure_number': FieldDescriptor(
-            _unicode_or_empty,
-            False,
-            'Номер строения',
+            data_type=_unicode_or_empty,
+            required=False,
+            description='Номер строения',
         ),
         'date_of_creation': FieldDescriptor(
-            _date,
-            True,
-            'Начало действия записи',
+            data_type=_date,
+            required=True,
+            description='Начало действия записи',
         ),
         'date_of_update': FieldDescriptor(
-            _date,
-            True,
-            'Дата  внесения (обновления) записи',
+            data_type=_date,
+            required=True,
+            description='Дата  внесения (обновления) записи',
         ),
         'date_of_end': FieldDescriptor(
-            _date,
-            True,
-            'Окончание действия записи',
+            data_type=_date,
+            required=True,
+            description='Окончание действия записи',
+        ),
+        'region_code': FieldDescriptor(
+            data_type=_int,
+            required=True,
+            description='Код региона',
+        ),
+        'adm_parent_obj_id': FieldDescriptor(
+            data_type=_int,
+            required=False,
+            description='Родительский obj_id в административной иерархии'
+        ),
+        'adm_parent_guid': FieldDescriptor(
+            data_type=_uuid,
+            required=False,
+            description='Родительский guid в административной иерархии'
+        ),
+        'mun_parent_obj_id': FieldDescriptor(
+            data_type=_int,
+            required=False,
+            description='Родительский obj_id в муниципальной иерархии'
+        ),
+        'mun_parent_guid': FieldDescriptor(
+            data_type=_uuid,
+            required=False,
+            description='Родительский guid в муниципальной иерархии'
         ),
     }
 
