@@ -98,7 +98,7 @@ def get_address_object(obj_id, timeout=None):
     :param obj_id: ID адресного объекта ГАР.
     :param float timeout: Timeout запросов к серверу ГАР в секундах.
 
-    :rtype: m3_gar_client.data.AddressObject
+    :rtype: m3_gar_client.data.AddressObject or NoneType
     """
     from m3_gar_client import config
 
